@@ -6,6 +6,7 @@ import pandas as pd
 
 from rubicon_ml import domain
 from rubicon_ml.client import ArtifactMixin, Base, DataframeMixin, Experiment
+from rubicon_ml.client.utils.exception_handling import failsafe
 from rubicon_ml.client.utils.tags import filter_children
 from rubicon_ml.exceptions import RubiconException
 
@@ -110,20 +111,35 @@ class Project(Base, ArtifactMixin, DataframeMixin):
         return grouped_experiments
 
     def to_dask_df(self, group_by=None):
-        """Loads the project's data into dask dataframe(s) sorted by `created_at`.
-        This includes the experiment details along with parameters and metrics.
+        """DEPRECATED: Available for backwards compatibility."""
+        warnings.warn(
+            "`to_dask_df` is deprecated and will be removed in a future release. "
+            "use `to_df(df_type='dask') instead.",
+            DeprecationWarning,
+        )
+
+        return self.to_df(df_type="dask", group_by=group_by)
+
+    @failsafe
+    def to_df(self, df_type="pandas", group_by=None):
+        """Loads the project's data into dask or pandas dataframe(s) sorted by
+        `created_at`. This includes the experiment details along with parameters
+        and metrics.
 
         Parameters
         ----------
+        df_type : str, optional
+            The type of dataframe to return. Valid options include
+            ["dask", "pandas"]. Defaults to "pandas".
         group_by : str or None, optional
             How to group the project's experiments in the returned
             dataframe(s). Valid options include ["commit_hash"].
 
         Returns
         -------
-        dask.DataFrame or list of dask.DataFrame
-            If `group_by` is `None`, a dask dataframe holding the project's
-            data. Otherwise a list of dask dataframes holding the project's
+        pandas.DataFrame or list of pandas.DataFrame or dask.DataFrame or list of dask.DataFrame
+            If `group_by` is `None`, a dask or pandas dataframe holding the project's
+            data. Otherwise a list of dask or pandas dataframes holding the project's
             data grouped by `group_by`.
         """
         DEFAULT_COLUMNS = [
@@ -170,12 +186,16 @@ class Project(Base, ArtifactMixin, DataframeMixin):
 
             columns = DEFAULT_COLUMNS + list(parameter_names) + list(metric_names)
             df = pd.DataFrame.from_records(experiment_records, columns=columns)
-
             df = df.sort_values(by=["created_at"], ascending=False).reset_index(drop=True)
-            experiment_dfs[group] = dd.from_pandas(df, npartitions=1)
+
+            if df_type == "dask":
+                df = dd.from_pandas(df, npartitions=1)
+
+            experiment_dfs[group] = df
 
         return experiment_dfs if group_by is not None else list(experiment_dfs.values())[0]
 
+    @failsafe
     def log_experiment(
         self,
         name=None,
@@ -234,6 +254,7 @@ class Project(Base, ArtifactMixin, DataframeMixin):
 
         return Experiment(experiment, self)
 
+    @failsafe
     def experiment(self, id=None, name=None):
         """Get an experiment logged to this project by id or name.
 
@@ -269,6 +290,7 @@ class Project(Base, ArtifactMixin, DataframeMixin):
 
         return experiment
 
+    @failsafe
     def experiments(self, tags=[], qtype="or", name=None):
         """Get the experiments logged to this project.
 
@@ -292,6 +314,7 @@ class Project(Base, ArtifactMixin, DataframeMixin):
 
         return self._experiments
 
+    @failsafe
     def dataframes(self, tags=[], qtype="or", recursive=False, name=None):
         """Get the dataframes logged to this project.
 
